Index: demo/coloring.cc
===================================================================
--- demo/coloring.cc	(revision 2172)
+++ demo/coloring.cc	(revision 2207)
@@ -56,5 +56,5 @@
 
   UGraphReader<Graph> reader("coloring.lgf", graph);
-  Graph::NodeMap<xy<double> > coords(graph);
+  Graph::NodeMap<dim2::Point<double> > coords(graph);
   reader.readNodeMap("coords", coords);
   
Index: demo/disjoint_paths_demo.cc
===================================================================
--- demo/disjoint_paths_demo.cc	(revision 2174)
+++ demo/disjoint_paths_demo.cc	(revision 2207)
@@ -53,5 +53,5 @@
   Graph graph;
 
-  Graph::NodeMap<xy<double> > coords(graph);
+  Graph::NodeMap<dim2::Point<double> > coords(graph);
   Graph::Node source, target;
   GraphReader<Graph>("disjoint_paths_demo.lgf", graph).
@@ -99,5 +99,7 @@
     title("node disjoint path").copyright("(C) 2006 LEMON Project").drawArrows().
     edgeColors(composeMap(functorMap(color), sflow)).
-    coords(SGraph::combinedNodeMap(coords, shiftMap(coords, xy<double>(5, 0)))).
+    coords(SGraph::combinedNodeMap(coords,
+				   shiftMap(coords,
+					    dim2::Point<double>(5, 0)))).
     autoNodeScale().run();
 
Index: demo/graph_orientation.cc
===================================================================
--- demo/graph_orientation.cc	(revision 2172)
+++ demo/graph_orientation.cc	(revision 2207)
@@ -20,5 +20,5 @@
 #include <lemon/graph_reader.h>
 #include <lemon/iterable_maps.h>
-#include <lemon/xy.h>
+#include <lemon/dim2.h>
 #include <lemon/graph_to_eps.h>
 
@@ -46,5 +46,5 @@
   ListGraph::NodeMap<int> f(g); //in-deg requirement;
   ListGraph::NodeMap<int> label(g);
-  ListGraph::NodeMap<xy<double> > coords(g);
+  ListGraph::NodeMap<dim2::Point<double> > coords(g);
   
   try {
Index: demo/graph_to_eps_demo.cc
===================================================================
--- demo/graph_to_eps_demo.cc	(revision 2178)
+++ demo/graph_to_eps_demo.cc	(revision 2207)
@@ -49,5 +49,5 @@
   typedef ListGraph::NodeIt NodeIt;
   typedef ListGraph::Edge Edge;
-  typedef xy<int> Xy;
+  typedef dim2::Point<int> Point;
   
   Node n1=g.addNode();
@@ -57,5 +57,5 @@
   Node n5=g.addNode();
 
-  ListGraph::NodeMap<Xy> coords(g);
+  ListGraph::NodeMap<Point> coords(g);
   ListGraph::NodeMap<double> sizes(g);
   ListGraph::NodeMap<int> colors(g);
@@ -64,9 +64,9 @@
   ListGraph::EdgeMap<int> widths(g);
   
-  coords[n1]=Xy(50,50);  sizes[n1]=1; colors[n1]=1; shapes[n1]=0;
-  coords[n2]=Xy(50,70);  sizes[n2]=2; colors[n2]=2; shapes[n2]=2;
-  coords[n3]=Xy(70,70);  sizes[n3]=1; colors[n3]=3; shapes[n3]=0;
-  coords[n4]=Xy(70,50);  sizes[n4]=2; colors[n4]=4; shapes[n4]=1;
-  coords[n5]=Xy(85,60);  sizes[n5]=3; colors[n5]=5; shapes[n5]=2;
+  coords[n1]=Point(50,50);  sizes[n1]=1; colors[n1]=1; shapes[n1]=0;
+  coords[n2]=Point(50,70);  sizes[n2]=2; colors[n2]=2; shapes[n2]=2;
+  coords[n3]=Point(70,70);  sizes[n3]=1; colors[n3]=3; shapes[n3]=0;
+  coords[n4]=Point(70,50);  sizes[n4]=2; colors[n4]=4; shapes[n4]=1;
+  coords[n5]=Point(85,60);  sizes[n5]=3; colors[n5]=5; shapes[n5]=2;
   
   Edge e;
@@ -184,10 +184,10 @@
   ListGraph h;
   ListGraph::NodeMap<int> hcolors(h);
-  ListGraph::NodeMap<Xy> hcoords(h);
+  ListGraph::NodeMap<Point> hcoords(h);
   
   int cols=int(sqrt(double(palette.size())));
   for(int i=0;i<int(paletteW.size());i++) {
     Node n=h.addNode();
-    hcoords[n]=Xy(i%cols,i/cols);
+    hcoords[n]=Point(i%cols,i/cols);
     hcolors[n]=i;
   }
Index: demo/grid_ugraph_demo.cc
===================================================================
--- demo/grid_ugraph_demo.cc	(revision 2172)
+++ demo/grid_ugraph_demo.cc	(revision 2207)
@@ -21,5 +21,5 @@
 #include <lemon/graph_to_eps.h>
 #include <lemon/bfs.h>
-#include <lemon/xy.h>
+#include <lemon/dim2.h>
 
 #include <iostream>
Index: demo/min_route.cc
===================================================================
--- demo/min_route.cc	(revision 1959)
+++ demo/min_route.cc	(revision 2207)
@@ -23,5 +23,5 @@
 #include <lemon/dijkstra.h>
 #include <lemon/maps.h>
-#include <lemon/xy.h>
+#include <lemon/dim2.h>
 #include <lemon/graph_reader.h>
 
@@ -47,5 +47,5 @@
   typedef typename CoordMap::Key Key;
 
-  PotentialMap(const CoordMap& _coord, const xy<double>& _target)
+  PotentialMap(const CoordMap& _coord, const dim2::Point<double>& _target)
     : coord(_coord), target(_target) {}
 
@@ -56,5 +56,5 @@
 private:
   const CoordMap& coord;
-  xy<double> target;
+  dim2::Point<double> target;
 };
 
@@ -87,5 +87,5 @@
   typedef Graph::NodeIt NodeIt;
   typedef Graph::EdgeMap<double> LengthMap;
-  typedef Graph::NodeMap<xy<double> > CoordMap;
+  typedef Graph::NodeMap<dim2::Point<double> > CoordMap;
 
   SmartGraph graph;
@@ -95,7 +95,7 @@
   
   CoordMap coord(graph);
-  XMap<CoordMap> xcoord = xMap(coord);
+  dim2::XMap<CoordMap> xcoord = xMap(coord);
   reader.readNodeMap("coordinates_x", xcoord);
-  YMap<CoordMap> ycoord = yMap(coord);
+  dim2::YMap<CoordMap> ycoord = yMap(coord);
   reader.readNodeMap("coordinates_y", ycoord);
 
Index: demo/strongly_connected_orientation.cc
===================================================================
--- demo/strongly_connected_orientation.cc	(revision 2174)
+++ demo/strongly_connected_orientation.cc	(revision 2207)
@@ -79,5 +79,5 @@
 
   UGraph ugraph;
-  UGraph::NodeMap<xy<double> > coords(ugraph);
+  UGraph::NodeMap<dim2::Point<double> > coords(ugraph);
   UGraphReader<UGraph>("strongly_connected_orientation.lgf", ugraph).
     readNodeMap("coords", coords).run();
Index: demo/topology_demo.cc
===================================================================
--- demo/topology_demo.cc	(revision 2174)
+++ demo/topology_demo.cc	(revision 2207)
@@ -21,5 +21,5 @@
 #include <lemon/graph_to_eps.h>
 #include <lemon/graph_reader.h>
-#include <lemon/xy.h>
+#include <lemon/dim2.h>
 
 #include <iostream>
@@ -50,5 +50,5 @@
 
   Graph graph;
-  Graph::NodeMap<xy<double> > coords(graph);
+  Graph::NodeMap<dim2::Point<double> > coords(graph);
 
   UGraphReader<Graph>("u_components.lgf", graph).
@@ -75,5 +75,5 @@
 
   Graph graph;
-  Graph::NodeMap<xy<double> > coords(graph);
+  Graph::NodeMap<dim2::Point<double> > coords(graph);
 
   GraphReader<Graph>("dir_components.lgf", graph).
@@ -105,5 +105,5 @@
 
   Graph graph;
-  Graph::NodeMap<xy<double> > coords(graph);
+  Graph::NodeMap<dim2::Point<double> > coords(graph);
 
   UGraphReader<Graph>("u_components.lgf", graph).
@@ -135,5 +135,5 @@
 
   Graph graph;
-  Graph::NodeMap<xy<double> > coords(graph);
+  Graph::NodeMap<dim2::Point<double> > coords(graph);
 
   UGraphReader<Graph>("u_components.lgf", graph).
@@ -164,5 +164,5 @@
 
   Graph graph;
-  Graph::NodeMap<xy<double> > coords(graph);
+  Graph::NodeMap<dim2::Point<double> > coords(graph);
 
   UGraphReader<Graph>("partitions.lgf", graph).

Index: demo/descriptor_map_demo.cc
===================================================================
--- demo/descriptor_map_demo.cc	(revision 2081)
+++ demo/descriptor_map_demo.cc	(revision 2207)
@@ -30,5 +30,5 @@
 #include <lemon/graph_utils.h>
 #include <lemon/graph_writer.h>
-#include <lemon/xy.h>
+#include <lemon/dim2.h>
 #include <lemon/graph_to_eps.h>
 
@@ -41,5 +41,5 @@
 using namespace lemon;
 
 // Special xy<double> map type 
 //
 // It gives back a position for each node. The position of the nodes
@@ -52,5 +52,5 @@
 public:
 
-  typedef xy<double> Value;
+  typedef dim2::Point<double> Value;
   typedef typename Graph::Node Key;
 
@@ -119,5 +119,5 @@
   // Make postscript from the graph.
     
-  CircleMap<Graph> coords(graph, xy<double>(0.0, 0.0), 10.0);
+  CircleMap<Graph> coords(graph, dim2::Point<double>(0.0, 0.0), 10.0);
     
   graphToEps(graph,"descriptor_map_demo.eps").scaleToA4().
@@ -41,5 +41,5 @@
 using namespace lemon;
 
-// Special xy<double> map type 
+// Special dim2::Point<double> map type 
 //
 // It gives back a position for each node. The position of the nodes